==> haskell-interpolate-0.2.1-453-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-FobNQgTjxrN4EK1Fzfo0G5
key:                  interpolate-0.2.1-FobNQgTjxrN4EK1Fzfo0G5
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  166f23e7d5e1e712bdf7a855de27e5f7
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-FobNQgTjxrN4EK1Fzfo0G5
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-97ow0rQaH9KAcgq1IgIaIQ
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.1-454-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-4DxuhWmtOrn5tIkRzGgG1I
key:                  interpolate-0.2.1-4DxuhWmtOrn5tIkRzGgG1I
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  995c3ce77d4e8ad98e570e3c93e15b3c
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-4DxuhWmtOrn5tIkRzGgG1I
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-5WFitTxLlY3F4m3fvGyHMw
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
